@@ -134,7 +134,7 @@ KigDocument* KigFilterDrgeo::load( const QString& file )
   }
 
 #ifdef DRGEO_DEBUG
-  kDebug() << "drgeo file " << file;
+  qDebug() << "drgeo file " << file;
 #endif
 
   for ( QDomNode n = main.firstChild(); ! n.isNull(); n = n.nextSibling() )
@@ -146,7 +146,7 @@ KigDocument* KigFilterDrgeo::load( const QString& file )
       if ( e.attribute("name") == myfig )
       {
 #ifdef DRGEO_DEBUG
-        kDebug() << "- Figure: '" << e.attribute("name") << "'";
+        qDebug() << "- Figure: '" << e.attribute("name") << "'";
 #endif
         bool grid = !e.attribute( "grid" ).isEmpty() &&
                     ( e.attribute( "grid" ) != "False" );
@@ -199,7 +199,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
     {
       DrGeoHierarchyElement elem;
 #ifdef DRGEO_DEBUG
-      kDebug() << "  * " << domelem.tagName() << "(" << domelem.attribute("type") << ")";
+      qDebug() << "  * " << domelem.tagName() << "(" << domelem.attribute("type") << ")";
 #endif
       for ( QDomNode c = domelem.firstChild(); ! c.isNull(); c = c.nextSibling() )
       {
@@ -216,7 +216,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
 
 #ifdef DRGEO_DEBUG
   QString x;
-  kDebug() << "+++ elems";
+  qDebug() << "+++ elems";
   for ( uint i = 0; i < elems.size(); ++i )
   {
     x = "";
@@ -224,7 +224,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
     {
       x += elems[i].parents[j] + '_';
     }
-    kDebug() << "  --> " << i << " - " << elems[i].id << " - " << x;
+    qDebug() << "  --> " << i << " - " << elems[i].id << " - " << x;
   }
 #endif
 
@@ -242,7 +242,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
   for (QDomNode a = f; ! a.isNull(); a = a.nextSibling() )
   {
 #ifdef DRGEO_DEBUG
-    kDebug() << "+++ id: " << curid;
+    qDebug() << "+++ id: " << curid;
 #endif
     const DrGeoHierarchyElement& el = elems[curid];
     std::vector<ObjectCalcer*> parents;
@@ -259,12 +259,12 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
     if ( parents.size() > 0 )
       for ( uint j = 0; j < parents.size(); ++j )
       {
-        kDebug() << "+++++++++ parent[" << j << "]: " << parents[j] << " - "
+        qDebug() << "+++++++++ parent[" << j << "]: " << parents[j] << " - "
                   << parents[j]->imp()->type()->internalName() << endl;
       }
     else
-      kDebug() << "+++++++++ parents: NO";
-    kDebug() << "+++++++++ " << domelem.tagName() << " - " << domelem.attribute("type");
+      qDebug() << "+++++++++ parents: NO";
+    qDebug() << "+++++++++ " << domelem.tagName() << " - " << domelem.attribute("type");
 #endif
 
     if ( domelem.isNull() ) continue;
@@ -400,7 +400,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         return 0;
       }
 #ifdef DRGEO_DEBUG
-      kDebug() << "+++++++++ oc:" << oc;
+      qDebug() << "+++++++++ oc:" << oc;
 #endif
     }
     else if( ( domelem.tagName() == "line" ) ||
@@ -507,7 +507,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         return 0;
       }
 #ifdef DRGEO_DEBUG
-      kDebug() << "+++++++++ oc:" << oc;
+      qDebug() << "+++++++++ oc:" << oc;
 #endif
     }
     else if( ( domelem.tagName() == "numeric" ) ||
@@ -634,7 +634,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         return 0;
       }
 #ifdef DRGEO_DEBUG
-      kDebug() << "+++++++++ oc:" << oc;
+      qDebug() << "+++++++++ oc:" << oc;
 #endif
     }
     else if ( domelem.tagName() == "angle" )
@@ -652,7 +652,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         return 0;
       }
 #ifdef DRGEO_DEBUG
-      kDebug() << "+++++++++ oc:" << oc;
+      qDebug() << "+++++++++ oc:" << oc;
 #endif
     }
     else if ( domelem.tagName() == "script" )
@@ -705,7 +705,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
         return 0;
       }
 #ifdef DRGEO_DEBUG
-      kDebug() << "+++++++++ oc:" << oc;
+      qDebug() << "+++++++++ oc:" << oc;
 #endif
     }
     else if ( ( domelem.tagName() == "boundingBox" ) ||
@@ -717,7 +717,7 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
     else
     {
 #ifdef DRGEO_DEBUG
-      kDebug() << ">>>>>>>>> UNKNOWN OBJECT";
+      qDebug() << ">>>>>>>>> UNKNOWN OBJECT";
 #endif
       notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
                                 "which Kig does not currently support.", domelem.tagName() , 
@@ -773,11 +773,11 @@ KigDocument* KigFilterDrgeo::importFigure( const QDomNode& f, const QString& fil
     holders.push_back( o );
 // calc()
 #ifdef DRGEO_DEBUG
-    kDebug() << ">>>>>>>>> calc";
+    qDebug() << ">>>>>>>>> calc";
 #endif
     holders[curid-1-nignored]->calc( *ret );
 #ifdef DRGEO_DEBUG
-    kDebug() << "+++++++++ oc: " << oc << " - "
+    qDebug() << "+++++++++ oc: " << oc << " - "
               << oc->imp()->type()->internalName() << endl;
 #endif
 
